@@ -56,6 +56,34 @@ def _find_instances(agent_class, host=None, config=None):
     return instances
 
 
+def _find_active_instances(agent_class, config=None):
+    """Find all instances of an Agent Class currently online, based on the
+    Agents known by the registry.
+
+    Args:
+        agent_class (str): Agent Class name to search for, must match Agent
+            Class defined by an OCS Agent (and thus also defined in the SCF.)
+        config (str): Path to the OCS Site Config File. If None the default
+            file in OCS_CONFIG_DIR will be used.
+
+    Returns:
+        list: List of instance-id's matching the given agent_class.
+
+    """
+    cfg = _load_site_config(config)
+
+    reg_client = OCSClient(cfg.hub.data['registry_address'])
+    _, _, session = reg_client.main.status()
+
+    instances = []
+    for entry in session['data'].values():
+        if entry['agent_class'] == agent_class:
+            instance_id = entry['agent_address'].split('.')[-1]
+            instances.append(instance_id)
+
+    return instances
+
+
 def create_clients(config=None, test_mode=False):
     """Create all clients needed for commanding a single platform.
 
@@ -74,17 +102,21 @@ def create_clients(config=None, test_mode=False):
                        'smurf': [smurf_client1, smurf_client2, smurf_client3]}
 
     """
+    clients = {}
+
     if test_mode:
         smurf_agent_class = 'SmurfFileEmulator'
     else:
         smurf_agent_class = 'PysmurfController'
 
-    acu_id = _find_instances('ACUAgent', config)
-    smurf_ids = _find_instances(smurf_agent_class, config)
+    acu_id = _find_active_instances('ACUAgent', config=config)
+    smurf_ids = _find_active_instances(smurf_agent_class, config=config)
 
-    acu_client = OCSClient(acu_id[0])
-    smurf_clients = [OCSClient(x) for x in smurf_ids]
+    if acu_id:
+        acu_client = OCSClient(acu_id[0])
+        clients['acu'] = acu_client
+    if smurf_ids:
+        smurf_clients = [OCSClient(x) for x in smurf_ids]
+        clients['smurf'] = smurf_clients
 
-    clients = {'acu': acu_client,
-               'smurf': smurf_clients}
     return clients
